﻿//numberSpreads.jsx
//An InDesign CS5.5 JavaScript
// Visit my website at http://benmilander.com/indesign_scripts for information on this and other useful scripts
/*
 This script will number the spreads in a document.
 The page layout should start with first spread having the leftmost page an even page number.
 Secondly, there should be a unique pagagraph style to be applied to the text frame to contain the spread number.  This should be set to the default before running the script.
 This script will create a new layer at the bottom of the layer stack and set its printing attribute to non printing.
 The script continues by creating a text frame in the upper left corner of each spread on this layer and inserting the spread number in the text frame with the default paragraph style.
 It does this on each spread, locks the layer and quits.
 The user can at this point use the paragraph style in a text variable anywhere on the page or on the master page to create printable spread numbers for the left and right pages.
 Script by
		Ben J. Milander, benmilander.com
	 	6/1/2012
    */
/* mod: Boris Kas, boriskasmoscow@gmail.com, www.adobeindesign.ru*/

var myDocument = app.activeDocument;
	//Make certain that user interaction (display of dialogs, etc.) is turned on.
app.scriptPreferences.userInteractionLevel = UserInteractionLevels.interactWithAll;
const myScriptName = "Number Spreads";
const myScriptVersion = "2.0";
const theAuthor = "Ben J. Milander";
var myBounds = [0,0, 20,100];
var whereNumbes;
var selectedParaStyleName;
var myIndex = 0;
    // Call the main function
main();	

function main(){
var myParaStyleList = new Array();
	// make sure a document is open
	if(app.documents.length != 0){
            app.activeDocument.viewPreferences.rulerOrigin = RulerOrigin.pageOrigin;            
            myParaStyleList = myGetParagraphStyleNames();
            var myWin = myDialog(myParaStyleList);
            var sh = myWin.show();
            if(sh==0) {exit();}
            spreadNubers();
         }
	else{
		alert("No documents are open. Please open a document and try again.");
	}
}

function myGetParagraphStyleNames()
{
var result = [];    
var myParagraphStyles = app.activeDocument.allParagraphStyles;
var myParagraphStyleName, obj;
for(var i=0; i < myParagraphStyles.length ; i++)
{
    myParagraphStyleName = myParagraphStyles[i].name;
    obj = myParagraphStyles[i];
    while(obj.parent instanceof ParagraphStyleGroup)
    {
        myParagraphStyleName = obj.parent.name + ":" + myParagraphStyleName;
        obj = obj.parent;        
    }
    result.push(myParagraphStyleName);
 } // for
result.shift(); // remove 'No Paragraph Style'
return result;
} // fnc
//******************************************* dialog ********************************
function myDialog(myStyles) 
{
	if(checkLayerExist()) 
    {
        var myTextFrame = app.activeDocument.layers.item("spreadNumbers").textFrames[0];
        myBounds = myTextFrame.geometricBounds;
        var myStyle = myTextFrame.paragraphs[0].appliedParagraphStyle;
        for(var i = 0; i < myStyles.length; i++)
        {
            if(myStyle == getParagraphStyleByName(myStyles[i])) break;
        }
        myIndex = i;
   }
    
    
    var myWin = new Window( "dialog", myScriptName );
	this.windowRef = myWin;
	myWin.orientation = "column";
	myWin.alignChildren = "center";
    
    // add panel
    myWin.Pnl = myWin.add("panel", undefined, "");
	myWin.Pnl.orientation = "column";

	// add grop 1 to panel 
	myWin.Pnl.inputGroup1 = myWin.Pnl.add("group");
	myWin.Pnl.inputGroup1.txt1 = myWin.Pnl.inputGroup1.add("statictext", undefined, "Apply Paragrah Style: ");
	myWin.Pnl.inputGroup1.dropdown = myWin.Pnl.inputGroup1.add("dropdownlist", undefined, myStyles);
	myWin.Pnl.inputGroup1.dropdown.preferredSize = [200, 20];
    myWin.Pnl.inputGroup1.dropdown.selection = myIndex;
    
    // add group 2 to panel
    var editTextForBounds = [];
    myWin.Pnl.inputGroup2 = myWin.Pnl.add("group");
    myWin.Pnl.inputGroup2.txt1 = myWin.Pnl.inputGroup2.add("statictext", undefined, "GeometricBounds: ");
    for(var i =0; i < 4; i++)
    {
        editTextForBounds[i] = myWin.Pnl.inputGroup2.add("edittext", undefined, myBounds[i]);
        editTextForBounds[i].characters = 5;
    } // for

    //add group 3 to panel
    myWin.Pnl.inputGroup3 = myWin.Pnl.add("group");
    myWin.Pnl.inputGroup3.orientation = "column";
    myWin.Pnl.inputGroup3.alignChildren = 'left'
    myWin.Pnl.inputGroup3.txt = myWin.Pnl.inputGroup3.add("statictext", undefined, "Spread Numbers:");
    myWin.Pnl.inputGroup3.radio1 = myWin.Pnl.inputGroup3.add('radiobutton', undefined, 'on Right Page');
    myWin.Pnl.inputGroup3.radio2 = myWin.Pnl.inputGroup3.add('radiobutton', undefined, 'on Left Page');
    myWin.Pnl.inputGroup3.radio3 = myWin.Pnl.inputGroup3.add('radiobutton', undefined, 'on Left Page and Right Page');
    myWin.Pnl.inputGroup3.radio1.value = true;
    
    // add buttons
    var mainButtons = myWin.add( "group" );
    myWin.okButton = mainButtons.add( "button", undefined, "Go" );
    myWin.okButton.onClick = function() 
    {
        if(myWin.Pnl.inputGroup3.radio1.value) { whereNumbes = 'RightPages'}
        else
        {
            if(myWin.Pnl.inputGroup3.radio2.value) { whereNumbes = 'LeftPages'}
            else { whereNumbes = 'RightLeftPages'}
        }
        for(var i =0; i < 4; i++)
        {
            myBounds[i] = editTextForBounds[i].text;
        } // for
        selectedParaStyleName = myWin.Pnl.inputGroup1.dropdown.selection.text;
        this.window.close( 1 );    
    } // okButton.onClick
    myWin.cancelButton = mainButtons.add( "button", undefined, "Cancel" );
    myWin.cancelButton.onClick = function() 
    {
        this.window.close( 0 );
        //exit();
    }
return myWin;
    
} // end of myDialog

function checkLayerExist()
{
    var myLayer = app.activeDocument.layers.item("spreadNumbers");
    try{
        myLayer.name
        return true;
    }
    catch(er)
    {
        return false;
    }
}

function spreadNubers()
{
    myDocument = app.activeDocument;
    if(!checkLayerExist()) // add layer
    {
        myNewLayer = addSpreadsNumbersLayer()
    }
    else 
    {
        myDocument.layers.item("spreadNumbers").remove();
        myNewLayer = addSpreadsNumbersLayer();
    }
        addFramesToLayer(myNewLayer);
} // fnc

function addSpreadsNumbersLayer()
{
    myDocument = app.activeDocument;
    var myNewLayer = myDocument.layers.add({name:"spreadNumbers"});
    var lastLayer = myDocument.layers[-1];
    myNewLayer.move(LocationOptions.AFTER, lastLayer);
    return myNewLayer;
}
function addFramesToLayer(myLayer)
{
    var myPages =  app.activeDocument.pages;
    var myStr;
    var paraStyle;
     for (var i = 0; i < myPages.length; i++) 
     {
         if(myPages[i].side == PageSideOptions.leftHand && whereNumbes == "RightPages") continue;
         if(myPages[i].side == PageSideOptions.rightHand && whereNumbes == "LeftPages") continue;
         myFrame = myPages[i].textFrames.add(myLayer, undefined, undefined,{geometricBounds:myBounds, name:"num"});
         if(myPages[i].side == PageSideOptions.leftHand)
         {
            myStr = "" + (Math.floor(i/2) + 2);
         }
        else
        {
            myStr = "" + (Math.floor(i/2) + 1);
        }
         myFrame.contents = myStr;
         // Apply para style
        try{
                    paraStyle = getParagraphStyleByName(selectedParaStyleName);
                    myFrame.paragraphs[0].appliedParagraphStyle = paraStyle;
          }
        catch(err) {}   
     }
}

function getParagraphStyleByName(myStyleName)
{
var myParagraphStyles = app.activeDocument.allParagraphStyles;
var myParagraphStyleName, obj;
for(var i=0; i < myParagraphStyles.length ; i++)
{
    myParagraphStyleName = myParagraphStyles[i].name;
    obj = myParagraphStyles[i];
    while(obj.parent instanceof ParagraphStyleGroup)
    {
        myParagraphStyleName = obj.parent.name + ":" + myParagraphStyleName;
        obj = obj.parent;        
    }
    if(myParagraphStyleName == myStyleName)  return myParagraphStyles[i];
 } // for
    
} // fnc